@@ -804,6 +804,7 @@ class OpenaiRequestAssembler(Assembler):
     def to_entity(self, dto: OpenaiRequestDTO):
         return OpenaiRequest(
             input = openai_chat_input_assembler.to_entity(dto.input),
+            job_timeout = UInt(dto.job_timeout),
             timeout = UInt(dto.timeout),
             request_id = None if dto.request_id is None else UStr(dto.request_id),
             others = None if dto.others is None else UDict(dto.others)
@@ -811,6 +812,7 @@ class OpenaiRequestAssembler(Assembler):
     def to_dto(self, x:OpenaiRequest):
         return OpenaiRequestDTO(
             input = openai_chat_input_assembler.to_dto(x.input),
+            job_timeout = x.job_timeout.get_value(),
             timeout = x.timeout.get_value(),
             request_id = None if x.request_id is None else x.request_id.get_value(),
             others = None if x.others is None else x.others.get_value()
@@ -844,8 +846,8 @@ class OpenaiItemAssembler(Assembler):
             item_id = UStr(dto.item_id),
             status = Status(dto.status),
             exception = None if dto.exception is None else UStr(dto.exception),
-            request = None if dto.request is None else search_request_assembler.to_entity(dto.request),
-            response = None if dto.response is None else search_response_assembler.to_entity(dto.response),
+            request = None if dto.request is None else openai_request_assembler.to_entity(dto.request),
+            response = None if dto.response is None else openai_response_assembler.to_entity(dto.response),
             entry_time = None if dto.entry_time is None else UDate(dto.entry_time),
             exit_time = None if dto.exit_time is None else UDate(dto.exit_time),
             create_time = None if dto.create_time is None else UDate(dto.create_time),
@@ -856,8 +858,8 @@ class OpenaiItemAssembler(Assembler):
             item_id = x.item_id.get_value(),
             status = x.status.get_value(),
             exception = None if x.exception is None else x.exception.get_value(),
-            request = None if x.request is None else search_request_assembler.to_dto(x.request),
-            response = None if x.response is None else search_response_assembler.to_dto(x.response),
+            request = None if x.request is None else openai_request_assembler.to_dto(x.request),
+            response = None if x.response is None else openai_response_assembler.to_dto(x.response),
             entry_time = None if x.entry_time is None else x.entry_time.get_value(),
             exit_time = None if x.exit_time is None else x.exit_time.get_value(),
             create_time = None if x.create_time is None else x.create_time.get_value(),
