@@ -804,6 +804,7 @@ class OpenaiRequestConverter(Converter):
     def to_entity(self, do: OpenaiRequestDO):
         return OpenaiRequest(
             input = openai_chat_input_converter.to_entity(do.input),
+            job_timeout = UInt(do.job_timeout),
             timeout = UInt(do.timeout),
             request_id = None if do.request_id is None else UStr(do.request_id),
             others = None if do.others is None else UDict(do.others)
@@ -811,6 +812,7 @@ class OpenaiRequestConverter(Converter):
     def to_do(self, x:OpenaiRequest):
         return OpenaiRequestDO(
             input = openai_chat_input_converter.to_do(x.input),
+            job_timeout = x.job_timeout.get_value(),
             timeout = x.timeout.get_value(),
             request_id = None if x.request_id is None else x.request_id.get_value(),
             others = None if x.others is None else x.others.get_value()
@@ -844,8 +846,8 @@ class OpenaiItemConverter(Converter):
             item_id = UStr(do.item_id),
             status = Status(do.status),
             exception = None if do.exception is None else UStr(do.exception),
-            request = None if do.request is None else search_request_converter.to_entity(do.request),
-            response = None if do.response is None else search_response_converter.to_entity(do.response),
+            request = None if do.request is None else openai_request_converter.to_entity(do.request),
+            response = None if do.response is None else openai_response_converter.to_entity(do.response),
             entry_time = None if do.entry_time is None else UDate(do.entry_time),
             exit_time = None if do.exit_time is None else UDate(do.exit_time),
             create_time = None if do.create_time is None else UDate(do.create_time),
@@ -856,8 +858,8 @@ class OpenaiItemConverter(Converter):
             item_id = x.item_id.get_value(),
             status = x.status.get_value(),
             exception = None if x.exception is None else x.exception.get_value(),
-            request = None if x.request is None else search_request_converter.to_do(x.request),
-            response = None if x.response is None else search_response_converter.to_do(x.response),
+            request = None if x.request is None else openai_request_converter.to_do(x.request),
+            response = None if x.response is None else openai_response_converter.to_do(x.response),
             entry_time = None if x.entry_time is None else x.entry_time.get_value(),
             exit_time = None if x.exit_time is None else x.exit_time.get_value(),
             create_time = None if x.create_time is None else x.create_time.get_value(),
