@@ -317,6 +317,7 @@ class OpenaiChatOutputDO(BaseModel):
 
 class OpenaiRequestDO(BaseModel):
     input: OpenaiChatInputDO
+    job_timeout: int = 30
     timeout: int = 300
     request_id: Optional[str] = None
     others: Optional[dict] = None
@@ -335,8 +336,8 @@ class OpenaiItemDO(BaseModel):
     item_id: str
     status: str
     exception: Optional[str] = None
-    request: Optional[SearchRequestDO] = None
-    response: Optional[SearchResponseDO] = None
+    request: Optional[OpenaiRequestDO] = None
+    response: Optional[OpenaiResponseDO] = None
     entry_time: Optional[datetime.datetime] = None
     exit_time: Optional[datetime.datetime] = None
     create_time: Optional[datetime.datetime] = None
