@@ -317,6 +317,7 @@ class OpenaiChatOutputDTO(BaseModel):
 
 class OpenaiRequestDTO(BaseModel):
     input: OpenaiChatInputDTO
+    job_timeout: int = 30
     timeout: int = 300
     request_id: Optional[str] = None
     others: Optional[dict] = None
@@ -335,8 +336,8 @@ class OpenaiItemDTO(BaseModel):
     item_id: str
     status: str
     exception: Optional[str] = None
-    request: Optional[SearchRequestDTO] = None
-    response: Optional[SearchResponseDTO] = None
+    request: Optional[OpenaiRequestDTO] = None
+    response: Optional[OpenaiResponseDTO] = None
     entry_time: Optional[datetime.datetime] = None
     exit_time: Optional[datetime.datetime] = None
     create_time: Optional[datetime.datetime] = None
