@@ -795,6 +795,7 @@ class OpenaiRequest(Entity):
     def __init__(
         self,
         input: OpenaiChatInput,
+        job_timeout: UInt = UInt(30),
         timeout: UInt = UInt(300),
         request_id: Optional[UStr] = None,
         others: Optional[UDict] = None,
@@ -806,6 +807,7 @@ class OpenaiRequest(Entity):
         del all_args['kwargs']
         super().__init__(**all_args)
         self.input = input
+        self.job_timeout = job_timeout
         self.timeout = timeout
         self.request_id = request_id
         self.others = others
@@ -839,8 +841,8 @@ class OpenaiItem(Entity):
         item_id: UStr,
         status: Status,
         exception: Optional[UStr] = None,
-        request: Optional[SearchRequest] = None,
-        response: Optional[SearchResponse] = None,
+        request: Optional[OpenaiRequest] = None,
+        response: Optional[OpenaiResponse] = None,
         entry_time: Optional[UDate] = None,
         exit_time: Optional[UDate] = None,
         create_time: Optional[UDate] = None,
