@@ -39,7 +39,7 @@ class UInt(ValueObject):
 
 class UFloat(ValueObject):
     def __init__(self, value=None):
-        if not isinstance(value, float):
+        if not isinstance(value, float) and not isinstance(value, int):
             raise TypeError('Value should be float type')
         super().__init__(value)
 
